import React, { useState } from 'react';
import SvgIcon from './SvgIcon';

/**
 * 申请权限弹窗组件
 * @param {Object} props
 * @param {boolean} props.show - 是否显示弹窗
 * @param {string} props.knowledgeBaseId - 知识库ID
 * @param {string} props.knowledgeBaseTitle - 知识库标题
 * @param {Function} props.onClose - 关闭弹窗的回调函数
 * @param {Function} props.onSubmit - 提交申请的回调函数，接收 requestData 参数
 * @param {boolean} props.isSubmitting - 是否正在提交
 */
export default function AccessRequestModal({
    show,
    knowledgeBaseId,
    knowledgeBaseTitle,
    onClose,
    onSubmit,
    isSubmitting = false,
}) {
    const [accessRequestData, setAccessRequestData] = useState({
        permissions: {
            can_read: true,
            can_edit: false,
            can_delete: false,
        },
        duration: '30', // 默认30天
        reason: '',
    });
    const [accessRequestErrors, setAccessRequestErrors] = useState({});

    const handleAccessRequestInputChange = (e) => {
        const { name, value } = e.target;
        if (name === 'duration') {
            setAccessRequestData((prev) => ({
                ...prev,
                [name]: value,
            }));
        } else if (name === 'reason') {
            setAccessRequestData((prev) => ({
                ...prev,
                [name]: value,
            }));
        }

        // Clear error when user types
        if (accessRequestErrors[name]) {
            setAccessRequestErrors((prev) => ({
                ...prev,
                [name]: '',
            }));
        }
    };

    const handlePermissionChange = (permissionType) => {
        setAccessRequestData((prev) => ({
            ...prev,
            permissions: {
                can_read: true, // 只读权限始终为true
                can_edit: permissionType === '编辑权限',
                can_delete: false, // 管理权限暂时不开放
            },
        }));
    };

    const validateAccessRequestForm = () => {
        const errors = {};

        if (!accessRequestData.reason.trim()) {
            errors.reason = '请输入申请原因';
        }

        setAccessRequestErrors(errors);
        return Object.keys(errors).length === 0;
    };

    const handleSubmitAccessRequest = () => {
        // Validate form
        if (!validateAccessRequestForm()) {
            return;
        }

        // 计算过期日期
        const expirationDate = new Date();
        expirationDate.setDate(expirationDate.getDate() + parseInt(accessRequestData.duration));
        const expiresAt = expirationDate.toISOString();

        // 调用父组件的提交函数
        onSubmit({
            knowledge_base: knowledgeBaseId,
            permissions: accessRequestData.permissions,
            reason: accessRequestData.reason,
            expires_at: expiresAt,
        });

        // 重置表单
        setAccessRequestData({
            permissions: {
                can_read: true,
                can_edit: false,
                can_delete: false,
            },
            duration: '30',
            reason: '',
        });
        setAccessRequestErrors({});
    };

    if (!show) return null;

    return (
        <div
            className='modal-backdrop'
            style={{
                position: 'fixed',
                top: 0,
                left: 0,
                right: 0,
                bottom: 0,
                backgroundColor: 'rgba(0, 0, 0, 0.5)',
                display: 'flex',
                alignItems: 'center',
                justifyContent: 'center',
                zIndex: 1050,
            }}
        >
            <div
                className='modal-content bg-white rounded shadow'
                style={{
                    width: '500px',
                    maxWidth: '90%',
                    padding: '20px',
                }}
            >
                <div className='modal-header d-flex justify-content-between align-items-center mb-3'>
                    <h5 className='modal-title m-0'>申请访问权限</h5>
                    <button
                        type='button'
                        className='btn-close'
                        onClick={onClose}
                        aria-label='Close'
                        disabled={isSubmitting}
                    ></button>
                </div>
                <div className='modal-body'>
                    <div className='mb-3'>
                        <label className='form-label'>知识库名称</label>
                        <input type='text' className='form-control' value={knowledgeBaseTitle} readOnly />
                    </div>
                    <div className='mb-3'>
                        <label className='form-label d-flex align-items-center gap-1'>
                            <SvgIcon className='key' />
                            访问级别 <span className='text-danger'>*</span>
                        </label>
                        <select
                            className='form-select'
                            value={accessRequestData.permissions.can_edit ? '编辑权限' : '只读访问'}
                            onChange={(e) => handlePermissionChange(e.target.value)}
                        >
                            <option value='只读访问'>只读访问</option>
                            <option value='编辑权限'>编辑权限</option>
                        </select>
                    </div>

                    <div className='mb-3'>
                        <label className='form-label d-flex align-items-center gap-1'>
                            <SvgIcon className='calendar' />
                            访问时长 <span className='text-danger'>*</span>
                        </label>
                        <select
                            className='form-select'
                            name='duration'
                            value={accessRequestData.duration}
                            onChange={handleAccessRequestInputChange}
                        >
                            <option value='7'>7天</option>
                            <option value='15'>15天</option>
                            <option value='30'>30天</option>
                            <option value='60'>60天</option>
                            <option value='90'>90天</option>
                            <option value='180'>180天</option>
                            <option value='365'>365天</option>
                        </select>
                    </div>
                    <div className='mb-3'>
                        <label className='form-label d-flex align-items-center gap-1'>
                            <SvgIcon className='chat' />
                            申请原因 <span className='text-danger'>*</span>
                        </label>
                        <textarea
                            className={`form-control ${accessRequestErrors.reason ? 'is-invalid' : ''}`}
                            id='reason'
                            name='reason'
                            rows='3'
                            value={accessRequestData.reason}
                            onChange={handleAccessRequestInputChange}
                            placeholder='请输入申请原因'
                        ></textarea>
                        {accessRequestErrors.reason && (
                            <div className='invalid-feedback'>{accessRequestErrors.reason}</div>
                        )}
                    </div>
                </div>
                <div className='modal-footer gap-2'>
                    <button type='button' className='btn btn-secondary' onClick={onClose} disabled={isSubmitting}>
                        取消
                    </button>
                    <button
                        type='button'
                        className='btn btn-dark'
                        onClick={handleSubmitAccessRequest}
                        disabled={isSubmitting}
                    >
                        {isSubmitting ? (
                            <>
                                <span
                                    className='spinner-border spinner-border-sm me-2'
                                    role='status'
                                    aria-hidden='true'
                                ></span>
                                提交中...
                            </>
                        ) : (
                            '提交申请'
                        )}
                    </button>
                </div>
            </div>
        </div>
    );
}
