import React, { useState, useEffect } from 'react';
import { useNavigate } from 'react-router-dom';
import { useDispatch, useSelector } from 'react-redux';
import { showNotification } from '../../../store/notification.slice';
import {
    updateKnowledgeBase,
    deleteKnowledgeBase,
    changeKnowledgeBaseType,
    getKnowledgeBaseDocuments,
} from '../../../store/knowledgeBase/knowledgeBase.thunks';

// 导入拆分的组件
import Breadcrumb from './components/Breadcrumb';
import KnowledgeBaseForm from './components/KnowledgeBaseForm';
import DeleteConfirmModal from './components/DeleteConfirmModal';
import UserPermissionsManager from './components/UserPermissionsManager';
import FileUploadModal from './components/FileUploadModal';
import DocumentList from './components/DocumentList';

// 部门和组别的映射关系
const departmentGroups = {
    技术部: ['开发组', '测试组', '运维组', '架构组', '安全组'],
    产品部: ['产品规划组', '用户研究组', '交互设计组', '项目管理组'],
    市场部: ['品牌推广组', '市场调研组', '客户关系组', '社交媒体组'],
    行政部: ['人事组', '财务组', '行政管理组', '后勤组'],
};

// 部门列表
const departments = Object.keys(departmentGroups);

export default function SettingsTab({ knowledgeBase }) {
    const dispatch = useDispatch();
    const navigate = useNavigate();
    const currentUser = useSelector((state) => state.auth.user);
    const isAdmin = currentUser?.role === 'admin';

    // State for knowledge base form
    const [knowledgeBaseForm, setKnowledgeBaseForm] = useState({
        permissions: knowledgeBase.permissions,
        name: knowledgeBase.name,
        desc: knowledgeBase.desc || knowledgeBase.description || '',
        type: knowledgeBase.type || 'private', // 默认为私有知识库
        original_type: knowledgeBase.type || 'private', // 存储原始类型用于比较
        department: knowledgeBase.department || '',
        group: knowledgeBase.group || '',
        original_department: knowledgeBase.department || '',
        original_group: knowledgeBase.group || '',
    });
    const [formErrors, setFormErrors] = useState({});
    const [isSubmitting, setIsSubmitting] = useState(false);
    const [showDeleteConfirm, setShowDeleteConfirm] = useState(false);
    const [availableGroups, setAvailableGroups] = useState([]);
    const [showUploadModal, setShowUploadModal] = useState(false);

    // 获取文档列表
    useEffect(() => {
        if (knowledgeBase?.id) {
            dispatch(getKnowledgeBaseDocuments({ knowledge_base_id: knowledgeBase.id }));
        }
    }, [dispatch, knowledgeBase?.id]);

    // 当部门变化时，更新可选的组别
    useEffect(() => {
        if (knowledgeBaseForm.department && departmentGroups[knowledgeBaseForm.department]) {
            setAvailableGroups(departmentGroups[knowledgeBaseForm.department]);
            // 如果已选择的组别不在新部门的选项中，则重置组别
            if (!departmentGroups[knowledgeBaseForm.department].includes(knowledgeBaseForm.group)) {
                setKnowledgeBaseForm((prev) => ({
                    ...prev,
                    group: '',
                }));
            }
        } else {
            setAvailableGroups([]);
            setKnowledgeBaseForm((prev) => ({
                ...prev,
                group: '',
            }));
        }
    }, [knowledgeBaseForm.department]);

    // 初始化可用组别
    useEffect(() => {
        if (knowledgeBase.department && departmentGroups[knowledgeBase.department]) {
            setAvailableGroups(departmentGroups[knowledgeBase.department]);
        }
    }, [knowledgeBase]);

    // Handle knowledge base form input change
    const handleInputChange = (e) => {
        const { name, value } = e.target;

        // 检查如果是类型更改，确保用户有权限
        if (name === 'type') {
            const role = currentUser?.role;
            let allowed = false;

            // 根据角色判断可以选择的知识库类型
            if (role === 'admin') {
                // 管理员可以选择任何类型
                allowed = ['admin', 'leader', 'member', 'private', 'secret'].includes(value);
            } else if (role === 'leader') {
                // 组长只能选择 member 和 private
                allowed = ['admin', 'member', 'private'].includes(value);
            } else {
                // 普通成员只能选择公共和private
                allowed = ['admin', 'private'].includes(value);
            }

            if (!allowed) {
                dispatch(
                    showNotification({
                        message: '您没有权限设置此类型的知识库',
                        type: 'warning',
                    })
                );
                return;
            }
        }

        setKnowledgeBaseForm((prev) => ({
            ...prev,
            [name]: value,
        }));

        // Clear error if exists
        if (formErrors[name]) {
            setFormErrors((prev) => ({
                ...prev,
                [name]: '',
            }));
        }
    };

    // Validate knowledge base form
    const validateForm = () => {
        const errors = {};
        // 私有知识库不需要部门和组别
        const isPrivate = knowledgeBaseForm.type === 'private';

        if (!knowledgeBaseForm.name.trim()) {
            errors.name = '请输入知识库名称';
        }

        if (!knowledgeBaseForm.desc.trim()) {
            errors.desc = '请输入知识库描述';
        }

        if (!knowledgeBaseForm.type) {
            errors.type = '请选择知识库类型';
        }

        // 只有非私有知识库需要验证部门和组别
        if (!isPrivate) {
            if (isAdmin && !knowledgeBaseForm.department) {
                errors.department = '请选择部门';
            }

            if (isAdmin && !knowledgeBaseForm.group) {
                errors.group = '请选择组别';
            }
        }

        setFormErrors(errors);
        return Object.keys(errors).length === 0;
    };

    // 检查是否有部门或组别变更
    const hasDepartmentOrGroupChanged = () => {
        return (
            knowledgeBaseForm.department !== knowledgeBaseForm.original_department ||
            knowledgeBaseForm.group !== knowledgeBaseForm.original_group
        );
    };

    // 单独处理类型更改
    const handleTypeChange = (newType) => {
        if (!currentUser) {
            dispatch(
                showNotification({
                    message: '用户信息不完整，无法更改类型',
                    type: 'warning',
                })
            );
            return;
        }

        // 所有用户都可以修改为admin或private类型，无需额外检查
        if (newType !== 'admin' && newType !== 'private' && currentUser.role === 'member') {
            dispatch(
                showNotification({
                    message: '您只能将知识库修改为公共(admin)或私有(private)类型',
                    type: 'warning',
                })
            );
            return;
        }

        if (isAdmin && !validateForm()) {
            return;
        }

        setIsSubmitting(true);

        // 私有知识库不需要部门和组别
        const isPrivate = newType === 'private';
        const department = isPrivate ? '' : isAdmin ? knowledgeBaseForm.department : currentUser.department || '';
        const group = isPrivate ? '' : isAdmin ? knowledgeBaseForm.group : currentUser.group || '';

        dispatch(
            changeKnowledgeBaseType({
                id: knowledgeBase.id,
                type: newType,
                department,
                group,
            })
        )
            .unwrap()
            .then((updatedKB) => {
                // 更新表单显示
                setKnowledgeBaseForm((prev) => ({
                    ...prev,
                    type: updatedKB.type,
                    original_type: updatedKB.type,
                    department: updatedKB.department,
                    original_department: updatedKB.department,
                    group: updatedKB.group,
                    original_group: updatedKB.group,
                }));

                dispatch(
                    showNotification({
                        message: `知识库类型已更新为 ${updatedKB.type}`,
                        type: 'success',
                    })
                );
                setIsSubmitting(false);
            })
            .catch((error) => {
                dispatch(
                    showNotification({
                        message: `类型更新失败: ${error || '未知错误'}`,
                        type: 'danger',
                    })
                );
                setIsSubmitting(false);
            });
    };

    // Handle form submission
    const handleSubmit = (e) => {
        e.preventDefault();

        // Validate form
        if (!validateForm()) {
            return;
        }

        setIsSubmitting(true);

        // 检查类型是否有更改，如果有，则使用单独的API更新类型
        if (knowledgeBaseForm.type !== knowledgeBaseForm.original_type || (isAdmin && hasDepartmentOrGroupChanged())) {
            handleTypeChange(knowledgeBaseForm.type);
            return;
        }

        // Dispatch update knowledge base action (不包含类型更改)
        dispatch(
            updateKnowledgeBase({
                id: knowledgeBase.id,
                data: {
                    name: knowledgeBaseForm.name,
                    desc: knowledgeBaseForm.desc,
                    description: knowledgeBaseForm.desc, // Add description field for compatibility
                },
            })
        )
            .unwrap()
            .then(() => {
                dispatch(
                    showNotification({
                        message: '知识库更新成功',
                        type: 'success',
                    })
                );
                setIsSubmitting(false);
            })
            .catch((error) => {
                dispatch(
                    showNotification({
                        message: `更新失败: ${error || '未知错误'}`,
                        type: 'danger',
                    })
                );
                setIsSubmitting(false);
            });
    };

    // Handle knowledge base deletion
    const handleDelete = () => {
        setIsSubmitting(true);

        // Dispatch delete knowledge base action
        dispatch(deleteKnowledgeBase(knowledgeBase.id))
            .unwrap()
            .then(() => {
                dispatch(
                    showNotification({
                        message: '知识库已删除',
                        type: 'success',
                    })
                );
                // Navigate back to knowledge base list
                // Redux store 已在 reducer 中更新，不需要重新调用接口获取知识库列表
                navigate('/knowledge-base');
            })
            .catch((error) => {
                dispatch(
                    showNotification({
                        message: `删除失败: ${error || '未知错误'}`,
                        type: 'danger',
                    })
                );
                setIsSubmitting(false);
                setShowDeleteConfirm(false);
            });
    };

    return (
        <>
            {/* Breadcrumb navigation */}
            <Breadcrumb knowledgeBase={knowledgeBase} activeTab='settings' />

            {/* Knowledge Base Form */}
            <KnowledgeBaseForm
                formData={knowledgeBaseForm}
                formErrors={formErrors}
                isSubmitting={isSubmitting}
                onInputChange={handleInputChange}
                onSubmit={handleSubmit}
                onDelete={() => setShowDeleteConfirm(true)}
                onTypeChange={handleTypeChange}
                isAdmin={isAdmin}
                departments={departments}
                availableGroups={availableGroups}
            />

            {/* Document Management Section */}
            <div className='card border-0 shadow-sm mt-4'>
                <div className='card-body'>
                    <div className='d-flex justify-content-between align-items-center mb-4'>
                        <h5 className='card-title m-0'>文档管理</h5>
                        <button className='btn btn-primary' onClick={() => setShowUploadModal(true)}>
                            上传文档
                        </button>
                    </div>

                    <DocumentList knowledgeBaseId={knowledgeBase.id} />
                </div>
            </div>

            {/* File Upload Modal */}
            <FileUploadModal
                show={showUploadModal}
                onClose={() => setShowUploadModal(false)}
                knowledgeBaseId={knowledgeBase.id}
            />

            {/* User Permissions Manager */}
            {/* <UserPermissionsManager knowledgeBase={knowledgeBase} /> */}

            {/* Delete confirmation modal */}
            <DeleteConfirmModal
                show={showDeleteConfirm}
                title={knowledgeBase.name}
                isSubmitting={isSubmitting}
                onCancel={() => setShowDeleteConfirm(false)}
                onConfirm={handleDelete}
            />
        </>
    );
}
