import React, { useState, useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { useLocation } from 'react-router-dom';
import { showNotification } from '../../../store/notification.slice';
import {
    fetchPermissionsThunk,
    approvePermissionThunk,
    rejectPermissionThunk,
} from '../../../store/permissions/permissions.thunks';
import { resetOperationStatus } from '../../../store/permissions/permissions.slice';
import './PendingRequests.css'; // 引入外部CSS文件
import SvgIcon from '../../../components/SvgIcon';
import RequestDetailSlideOver from './RequestDetailSlideOver';

export default function PendingRequests() {
    const dispatch = useDispatch();
    const location = useLocation();
    const [responseMessage, setResponseMessage] = useState('');
    const [showResponseInput, setShowResponseInput] = useState(false);
    const [currentRequestId, setCurrentRequestId] = useState(null);
    const [isApproving, setIsApproving] = useState(false);
    const [selectedRequest, setSelectedRequest] = useState(null);
    const [showSlideOver, setShowSlideOver] = useState(false);

    // 从Redux store获取权限申请列表状态
    const {
        results: permissionRequests,
        status: fetchStatus,
        error: fetchError,
        page: currentPage,
        page_size: pageSize,
        total,
    } = useSelector((state) => state.permissions.pending);

    // 计算总页数
    const totalPages = Math.ceil(total / pageSize) || 1;

    // 从Redux store获取批准/拒绝操作的状态
    const {
        status: approveRejectStatus,
        error: approveRejectError,
        currentId: processingId,
    } = useSelector((state) => state.permissions.approveReject);

    // 获取待处理申请列表
    useEffect(() => {
        dispatch(fetchPermissionsThunk({ page: currentPage, page_size: pageSize }));
    }, [dispatch, currentPage, pageSize]);

    // 处理从通知中心跳转过来的请求
    useEffect(() => {
        if (location.state?.showRequestDetail) {
            const { requestId, requestData } = location.state;
            setSelectedRequest(requestData);
            setShowSlideOver(true);
            // 清除 location state
            window.history.replaceState({}, document.title);
        }
    }, [location.state]);

    // 监听批准/拒绝操作的状态变化
    useEffect(() => {
        if (approveRejectStatus === 'succeeded') {
            dispatch(
                showNotification({
                    message: isApproving ? '已批准申请' : '已拒绝申请',
                    type: 'success',
                })
            );
            setShowResponseInput(false);
            setCurrentRequestId(null);
            setResponseMessage('');
            setShowSlideOver(false);
            setSelectedRequest(null);

            // 重新获取申请列表
            dispatch(fetchPermissionsThunk({ page: currentPage, page_size: pageSize }));

            // 重置状态
            dispatch(resetOperationStatus());
        } else if (approveRejectStatus === 'failed') {
            dispatch(
                showNotification({
                    message: approveRejectError || '处理申请失败',
                    type: 'danger',
                })
            );
            // 重置状态
            dispatch(resetOperationStatus());
        }
    }, [approveRejectStatus, approveRejectError, dispatch, isApproving, currentPage, pageSize]);

    // 打开回复输入框
    const handleOpenResponseInput = (requestId, approving) => {
        setCurrentRequestId(requestId);
        setIsApproving(approving);
        setShowResponseInput(true);
    };

    // 关闭回复输入框
    const handleCloseResponseInput = () => {
        setShowResponseInput(false);
        setCurrentRequestId(null);
        setResponseMessage('');
    };

    // 处理申请（批准或拒绝）
    const handleProcessRequest = () => {
        if (!currentRequestId) return;

        const params = {
            id: currentRequestId,
            responseMessage,
        };

        if (isApproving) {
            dispatch(approvePermissionThunk(params));
        } else {
            dispatch(rejectPermissionThunk(params));
        }
    };

    // 处理行点击，显示滑动面板
    const handleRowClick = (request) => {
        setSelectedRequest(request);
        setShowSlideOver(true);
    };

    // 关闭滑动面板
    const handleCloseSlideOver = () => {
        setShowSlideOver(false);
        setTimeout(() => {
            setSelectedRequest(null);
        }, 300); // 等待动画结束后再清除选中的申请
    };

    // 直接处理申请（不显示弹窗）
    const handleDirectProcess = (requestId, approve) => {
        setCurrentRequestId(requestId);
        setIsApproving(approve);

        const params = {
            id: requestId,
            responseMessage: approve ? '已批准' : '已拒绝',
        };

        if (approve) {
            dispatch(approvePermissionThunk(params));
        } else {
            dispatch(rejectPermissionThunk(params));
        }
    };

    // 处理页码变化
    const handlePageChange = (page) => {
        dispatch(fetchPermissionsThunk({ page, page_size: pageSize }));
    };

    // 渲染分页控件
    const renderPagination = () => {
        if (totalPages <= 1) return null;

        return (
            <div className='pagination-container'>
                <button
                    className='pagination-button'
                    onClick={() => handlePageChange(currentPage - 1)}
                    disabled={currentPage === 1}
                >
                    上一页
                </button>

                <div className='pagination-info'>
                    {currentPage} / {totalPages}
                </div>

                <button
                    className='pagination-button'
                    onClick={() => handlePageChange(currentPage + 1)}
                    disabled={currentPage === totalPages}
                >
                    下一页
                </button>
            </div>
        );
    };

    // 根据状态渲染不同的状态标签
    const renderStatusBadge = (status) => {
        switch (status) {
            case 'approved':
                return (
                    <span
                        className='badge bg-success-subtle text-success d-flex align-items-center gap-1'
                        style={{ width: 'fit-content' }}
                    >
                        <SvgIcon className='circle-check' />
                        已批准
                    </span>
                );
            case 'rejected':
                return (
                    <span
                        className='badge bg-danger-subtle text-danger d-flex align-items-center gap-1'
                        style={{ width: 'fit-content' }}
                    >
                        <SvgIcon className='circle-xmark' />
                        已拒绝
                    </span>
                );
            case 'pending':
                return (
                    <span
                        className='badge bg-warning-subtle text-warning d-flex align-items-center gap-1'
                        style={{ width: 'fit-content' }}
                    >
                        待处理
                    </span>
                );
            default:
                return null;
        }
    };

    // 获取知识库类型的中文描述
    const getKnowledgeBaseTypeText = (type) => {
        switch (type) {
            case 'admin':
                return '公共知识库';
            case 'member':
                return '组内知识库';
            case 'private':
                return '私人知识库';
            case 'leader':
                return '组长级知识库';
            case 'secret':
                return '私密知识库';
            default:
                return '未知类型';
        }
    };

    // 渲染加载状态
    if (fetchStatus === 'loading' && permissionRequests.length === 0) {
        return (
            <div className='text-center py-5'>
                <div className='spinner-border' role='status'>
                    <span className='visually-hidden'>加载中...</span>
                </div>
                <p className='mt-3'>加载权限申请...</p>
            </div>
        );
    }

    // 渲染错误状态
    if (fetchStatus === 'failed' && permissionRequests.length === 0) {
        return (
            <div className='alert alert-danger' role='alert'>
                {fetchError || '获取权限申请失败'}
            </div>
        );
    }

    // 渲染空状态
    if (permissionRequests.length === 0) {
        return (
            <div className='alert alert-info' role='alert'>
                暂无权限申请记录
            </div>
        );
    }

    // 渲染申请列表
    return (
        <>
            <div className='d-flex justify-content-between align-items-center mb-3'>
                <h5 className='mb-0'>权限申请列表</h5>
                <div className='badge bg-danger'>
                    {permissionRequests.filter((req) => req.status === 'pending').length}个待处理
                </div>
            </div>

            <div className='pending-requests-list'>
                {permissionRequests.map((request) => (
                    <div key={request.id} className='pending-request-item' onClick={() => handleRowClick(request)}>
                        <div className='request-header'>
                            <div className='user-info'>
                                <h6 className='mb-0'>{request.applicant.name || request.applicant.username}</h6>
                                <small className='text-muted'>{request.applicant.department || '未分配部门'}</small>
                            </div>
                            <div className='request-date'>{new Date(request.created_at).toLocaleDateString()}</div>
                        </div>

                        <div className='request-content'>
                            <div className='d-flex justify-content-between align-items-start mb-2'>
                                <div>
                                    <p className='mb-0'>申请访问：{request.knowledge_base.name}</p>
                                    <small className='text-muted'>
                                        类型：{getKnowledgeBaseTypeText(request.knowledge_base.type)}
                                    </small>
                                </div>
                                {renderStatusBadge(request.status)}
                            </div>

                            {request.permissions.can_edit ? (
                                <span
                                    className='badge bg-success-subtle text-success d-flex align-items-center gap-1'
                                    style={{ width: 'fit-content' }}
                                >
                                    <SvgIcon className={'circle-yes'} />
                                    完全访问
                                </span>
                            ) : (
                                request.permissions.can_read && (
                                    <span
                                        className='badge bg-warning-subtle text-warning d-flex align-items-center gap-1'
                                        style={{ width: 'fit-content' }}
                                    >
                                        <SvgIcon className={'eye'} />
                                        只读访问
                                    </span>
                                )
                            )}

                            {request.expires_at && (
                                <div className='mt-2'>
                                    <small className='text-muted'>
                                        到期时间: {new Date(request.expires_at).toLocaleDateString()}
                                    </small>
                                </div>
                            )}

                            {request.response_message && (
                                <div className='mt-2'>
                                    <small className='text-muted'>审批意见: {request.response_message}</small>
                                </div>
                            )}
                        </div>
                        <div className='request-actions'>
                            {(request.status === 'pending' && request.role === 'approver') ? (
                                <>
                                    <button
                                        className='btn btn-outline-danger btn-sm'
                                        onClick={(e) => {
                                            e.stopPropagation();
                                            handleDirectProcess(request.id, false);
                                        }}
                                        disabled={processingId === request.id && approveRejectStatus === 'loading'}
                                    >
                                        {processingId === request.id &&
                                        approveRejectStatus === 'loading' &&
                                        !isApproving
                                            ? '处理中...'
                                            : '拒绝'}
                                    </button>
                                    <button
                                        className='btn btn-outline-success btn-sm'
                                        onClick={(e) => {
                                            e.stopPropagation();
                                            handleDirectProcess(request.id, true);
                                        }}
                                        disabled={processingId === request.id && approveRejectStatus === 'loading'}
                                    >
                                        {processingId === request.id && approveRejectStatus === 'loading' && isApproving
                                            ? '处理中...'
                                            : '批准'}
                                    </button>
                                </>
                            ) : (
                                <div className='status-text'>
                                    {request.status === 'approved' ? '已批准' : '已拒绝'}
                                    {request.updated_at && (
                                        <small className='text-muted d-block'>
                                            {new Date(request.updated_at).toLocaleDateString()}
                                        </small>
                                    )}
                                </div>
                            )}
                        </div>
                    </div>
                ))}
            </div>

            {/* 分页控件 */}
            {renderPagination()}

            {/* 使用新的滑动面板组件 */}
            <RequestDetailSlideOver
                show={showSlideOver}
                onClose={handleCloseSlideOver}
                request={selectedRequest}
                onApprove={(id) => handleOpenResponseInput(id, true)}
                onReject={(id) => handleOpenResponseInput(id, false)}
                processingId={processingId}
                approveRejectStatus={approveRejectStatus}
                isApproving={isApproving}
            />

            {/* 回复输入弹窗 */}
            {showResponseInput && (
                <div className='modal fade show' style={{ display: 'block' }} tabIndex='-1'>
                    <div className='modal-dialog' style={{ zIndex: 9999 }}>
                        <div className='modal-content'>
                            <div className='modal-header'>
                                <h5 className='modal-title'>{isApproving ? '批准' : '拒绝'}申请</h5>
                                <button
                                    type='button'
                                    className='btn-close'
                                    onClick={handleCloseResponseInput}
                                    disabled={approveRejectStatus === 'loading'}
                                ></button>
                            </div>
                            <div className='modal-body'>
                                <div className='mb-3'>
                                    <label htmlFor='responseMessage' className='form-label'>
                                        审批意见
                                    </label>
                                    <textarea
                                        className='form-control'
                                        id='responseMessage'
                                        rows='3'
                                        value={responseMessage}
                                        onChange={(e) => setResponseMessage(e.target.value)}
                                        placeholder={isApproving ? '请输入批准意见（可选）' : '请输入拒绝理由（可选）'}
                                    ></textarea>
                                </div>
                            </div>
                            <div className='modal-footer'>
                                <button
                                    type='button'
                                    className='btn btn-secondary'
                                    onClick={handleCloseResponseInput}
                                    disabled={approveRejectStatus === 'loading'}
                                >
                                    取消
                                </button>
                                <button
                                    type='button'
                                    className={`btn ${isApproving ? 'btn-success' : 'btn-danger'}`}
                                    onClick={handleProcessRequest}
                                    disabled={approveRejectStatus === 'loading'}
                                >
                                    {approveRejectStatus === 'loading' ? (
                                        <>
                                            <span
                                                className='spinner-border spinner-border-sm me-1'
                                                role='status'
                                                aria-hidden='true'
                                            ></span>
                                            处理中...
                                        </>
                                    ) : isApproving ? (
                                        '确认批准'
                                    ) : (
                                        '确认拒绝'
                                    )}
                                </button>
                            </div>
                        </div>
                    </div>
                    <div className='modal-backdrop fade show'></div>
                </div>
            )}
        </>
    );
}
